<?php

namespace App\Http\Controllers;

use App\Rules\ValidPassword;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use Setting;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');

    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('home');
    }


    public function saveGeneral(Request $request)
    {

        $messages = [
            'analytics.regex' => 'Wrong format of Google Analytics Code',
            'email.email' => 'Wrong format of email, please provide a correct one.',
            'password.confirmed' => 'New Password and Password Confirmation does not match',
            'password.required_with' => 'You need to fill the new password',
            'password.different' => 'Password must be different from current',
            'old.required_with' => 'You need to fill your current password',
            'password_confirmation.same' => 'Password Confirmation and Password are not the same'
        ];

        $validator = Validator::make($request->all(), [
            'analytics' => array('nullable', 'regex:/^ua-\d{4,9}-\d{1,4}$/i'),
            'email' => 'nullable|email',
            'old' => array(new ValidPassword($request->old), 'nullable'),
            'password' => 'nullable|required_with:old|different:old',
            'password_confirmation' => 'same:password'

        ], $messages);

        if ($validator->fails()) {
            return response()->json(['error' => $validator->errors()]);
        } else {
            $user = Auth::user();
            if (!empty($request->input('sitename'))) {
                Setting::set('sitename', $request->input('sitename'));
            }

            if (!empty($request->input('description'))) {
                Setting::set('description', $request->input('description'));
            }
            if (!empty($request->input('analytics'))) {
                Setting::set('analytics', $request->input('analytics'));
            }

            if (!empty($request->input('copyrights'))) {
                Setting::set('copyrights', $request->input('copyrights'));
            }

            if (!empty($request->input('ad1'))) {
                Setting::set('ad1', $request->input('ad1'));
            }
            if (!empty($request->input('ad2'))) {
                Setting::set('ad2', $request->input('ad2'));
            }

            if (!empty($request->input('websites'))) {
                Setting::set('websites', $request->input('websites'));
            }

            if (!empty($request->input('email'))) {

                $user->email = $request->input('email');
                $user->save();
                Setting::set('email', $user->email);
            }

            if (!empty($request->input('old'))) {
                $user->password = bcrypt($request->input('password'));
                $user->save();
            }
            return response()->json(['success' => 'ok'], 200);
        }

    
    }


}
